@@ -8,7 +8,7 @@ def main():
 
     # Get the first slice
     slc = sim.slices[1]
-    data = slc.to_global()
+    data = slc.to_global(masked=True, fill=50)
 
     # Plot the slice
     plt.imshow(data[-1].T, vmin=19, vmax=20, origin="lower")
